// アイコンのサイズを任意に変更できる定数
const ICON_SIZE = 32

// ファビコンimgタグのキャッシュ
const faviconCache = {}

// サービスごとのファビコンURL
const serviceFavicons = {
  youtube: "https://www.youtube.com/favicon.ico",
  niconama: "https://nicolive.cdn.nimg.jp/relive/party1-static/images/common/favicon.afada.ico",
  twitch: "https://static.twitchcdn.net/assets/favicon-32-e29e246c157142c94346.png",
  twicas: "https://twitcasting.tv/favicon.ico",
  showroom: "https://www.showroom-live.com/favicon.ico",
  kick: "https://kick.com/favicon.ico",
  bilibili: "https://www.bilibili.com/favicon.ico",
  mixch: "https://mixch.tv/favicon.ico",
  mirrativ: "https://www.mirrativ.com/favicon.png",
  vtips: "https://v-tips.jp/assets/v-tips/favicons/favicon.ico?v=1.0.0",
  tiktok: "https://www.tiktok.com/favicon.ico"
}

// サービスごとのSVG
const serviceSVGs = {
  youtube: `<img src="data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 576 512' width='${ICON_SIZE}' height='${ICON_SIZE}' style='vertical-align:middle;margin-right:4px;'><path fill='%23FF0000' d='M549.7 124.1c-6.3-23.7-24.8-42.3-48.3-48.6C458.8 64 288 64 288 64S117.2 64 74.6 75.5c-23.5 6.3-42 24.9-48.3 48.6-11.4 42.9-11.4 132.3-11.4 132.3s0 89.4 11.4 132.3c6.3 23.7 24.8 41.5 48.3 47.8C117.2 448 288 448 288 448s170.8 0 213.4-11.5c23.5-6.3 42-24.2 48.3-47.8 11.4-42.9 11.4-132.3 11.4-132.3s0-89.4-11.4-132.3z'/><polygon fill='white' points='240,175.2 240,337.6 382.7,256.4'/></svg>" width="${ICON_SIZE}" height="${ICON_SIZE}" style="vertical-align:middle;margin-right:4px;" />`,
  // 他サービスはファビコンを利用
}

function getServiceIcon(service) {
  // SVGがあればSVG、なければファビコン（キャッシュ利用）
  if (serviceSVGs[service]) {
    return serviceSVGs[service]
  }
  if (faviconCache[service]) {
    return faviconCache[service]
  }
  const url = serviceFavicons[service]
  if (!url) return ''
  const tag = `<img src="${url}" width="${ICON_SIZE}" height="${ICON_SIZE}" style="vertical-align:middle;margin-right:4px;" />`
  faviconCache[service] = tag
  return tag
}

module.exports = {
  name: '配信サイトのアイコンをテンプレに付与するプラグイン',
  uid: 'com.onecomme.attach-service-icon',
  version: '1.0.2',
  author: '深紅の滴',
  url: 'https://nvl-game.tokyo/plugins/5509',
  permissions: ['filter.comment'],
  defaultState: {},
  filterComment(comment, service, userData) {
    const icon = getServiceIcon(comment.service)
    // badges配列の末尾にサービスアイコンバッジを追加
    if (icon && comment.data && Array.isArray(comment.data.badges)) {
      // imgタグのsrc部分だけを抽出
      let badgeUrl = '';
      const srcMatch = icon.match(/src="([^"]+)"/);
      if (srcMatch) {
        badgeUrl = srcMatch[1];
      }
      comment.data.badges.push({
        label: `${comment.service}アイコン`,
        url: badgeUrl
      });
    }
    return comment
  },
}